/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format.menus;

import java.io.Writer;
import java.io.IOException;
import org.w3c.dom.*;
import com.silverwrist.util.*;
import com.silverwrist.venice.servlets.format.ComponentRender;
import com.silverwrist.venice.servlets.format.RenderData;

abstract class LeftMenuItem implements ComponentRender
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String text;
  private boolean disabled = false;
  private boolean new_window = false;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected LeftMenuItem(Element elt)
  {
    DOMElementHelper h = new DOMElementHelper(elt);
    text = StringUtil.encodeHTML(h.getSubElementText("text"));
    if (h.hasChildElement("disabled"))
      disabled = true;
    if (h.hasChildElement("new-window"))
      new_window = true;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract functions which MUST be overridden
   *--------------------------------------------------------------------------------
   */

  protected abstract void appendURL(StringBuffer sbuf, RenderData rdat);

  /*--------------------------------------------------------------------------------
   * Implementations from interface ComponentRender
   *--------------------------------------------------------------------------------
   */

  public void renderHere(Writer out, RenderData rdat) throws IOException
  {
    StringBuffer buf = new StringBuffer();

    if (disabled)
      buf.append("<FONT COLOR=\"#CCCCCC\">");
    else
    { // write the <A> tag
      buf.append("<A HREF=\"");
      appendURL(buf,rdat);
      buf.append('"');
      if (new_window)
	buf.append(" TARGET=\"_blank\"");
      buf.append('>');

    } // end else (writing <A> tag)

    buf.append(text);
    if (disabled)
      buf.append("</FONT>");
    else
      buf.append("</A>");
    buf.append("<BR>\n");
    out.write(buf.toString());

  } // end renderHere

} // end class LeftMenuItem
